@@ -45,7 +45,7 @@ class NodeInfoDO(BaseModel):
     internet_pay_type: str
     pay_type: str
     security_group_id: List[str]
-    node_label: str
+    node_label: Union[str, Dict]
     cpu_number: int
     memory_size: float
     gpu_type: str
